# database: cyberbrau


# batch
CREATE TABLE batch(
    id INT(12) NOT NULL AUTO_INCREMENT,
    recipe_id INT(12) NOT NULL,
    start DATETIME NULL,
    complete DATETIME NULL,
    notes LONGTEXT NULL,
    rack_date DATETIME NULL,
    born_on DATETIME NULL,
    batch_name VARCHAR(32) NULL,
    og TEXT NULL,
    fg TEXT NULL,
    brewers_comments VARCHAR(255) NULL,
    brewers_name VARCHAR(128) NULL,
    type TINYINT(4) NOT NULL,
    active TINYINT(4) NOT NULL,
    sub_type TINYINT(4) DEFAULT 1 NULL,
    size SMALLINT(6) DEFAULT 5 NOT NULL,
    PRIMARY KEY (id)
);

# batch_lookup
CREATE TABLE batch_lookup(
    batch_id INT(12) NOT NULL,
    ing_id INT(12) NOT NULL,
    amount FLOAT NOT NULL,
    boiltime INT(12) NULL
);

# beer_subtypes
CREATE TABLE beer_subtypes(
    id TINYINT(4) NOT NULL AUTO_INCREMENT,
    name VARCHAR(32) NOT NULL,
    og VARCHAR(16) NOT NULL,
    fg VARCHAR(16) NULL,
    apv VARCHAR(8) NULL,
    srm VARCHAR(8) NULL,
    co2 VARCHAR(8) NULL,
    ibu VARCHAR(8) NULL,
    PRIMARY KEY (id)
);

# beer_types
CREATE TABLE beer_types(
    id TINYINT(4) NOT NULL AUTO_INCREMENT,
    name VARCHAR(16) NOT NULL,
    description MEDIUMTEXT NOT NULL,
    PRIMARY KEY (id)
);

# ingredients
CREATE TABLE ingredients(
    id INT(6) NOT NULL AUTO_INCREMENT,
    type VARCHAR(64) NOT NULL,
    name VARCHAR(64) NOT NULL,
    unit VARCHAR(16) NULL,
    prop1 VARCHAR(128) NULL,
    prop2 INT(11) NULL,
    PRIMARY KEY (id)
);

# observations
CREATE TABLE observations(
    id INT(12) NOT NULL AUTO_INCREMENT,
    batch_id INT(12) NOT NULL,
    drinkers_name VARCHAR(128) NOT NULL,
    app_rating TINYINT(4) NOT NULL,
    appearance VARCHAR(255) NULL,
    aroma_rating TINYINT(4) NOT NULL,
    aroma VARCHAR(255) NULL,
    taste_rating TINYINT(4) NOT NULL,
    taste VARCHAR(255) NULL,
    overall_rating TINYINT(4) NOT NULL,
    overall VARCHAR(255) NULL,
    comments VARCHAR(255) NULL,
    entered_date DATETIME NOT NULL,
    PRIMARY KEY (id)
);

# recipe_lookup
CREATE TABLE recipe_lookup(
    recipe_id INT(12) NOT NULL,
    ing_id INT(12) NOT NULL,
    amount FLOAT NOT NULL,
    boiltime INT(12) NULL
);

# recipes
CREATE TABLE recipes(
    id INT(12) NOT NULL AUTO_INCREMENT,
    name VARCHAR(128) NOT NULL,
    notes LONGTEXT NOT NULL,
    type TINYINT(4) NOT NULL,
    sub_type TINYINT(4) NULL,
    owner VARCHAR(16) NULL,
    size SMALLINT(8) DEFAULT 5 NOT NULL,
    PRIMARY KEY (id)
);

# schedule
CREATE TABLE schedule(
    msg_id TINYINT(4) NOT NULL AUTO_INCREMENT,
    email VARCHAR(64) NOT NULL,
    body VARCHAR(255) NOT NULL,
    send_date DATE NOT NULL,
    PRIMARY KEY (msg_id)
);

# users
CREATE TABLE users(
    user_id INT(12) NOT NULL AUTO_INCREMENT,
    username VARCHAR(16) NOT NULL,
    password VARCHAR(32) NOT NULL,
    email VARCHAR(64) NULL,
    PRIMARY KEY (user_id)
);



# beer subtypes
INSERT INTO beer_subtypes (id, name, og, fg, apv, srm, co2, ibu) VALUES (1,'None','0',NULL,NULL,NULL,NULL,NULL),(7,'American Amber Ale','1.044-56','1.006-16','4.5-5.5','11-18','2.2-2.8','20-40'),(8,'American Brown','1.040-55','1.010-18','4-5.9','15-22','1.5-2.5','25-60'),(9,'American Dark Lager','1.040-50','1.008-12','4-5.5','10-20','2.5-2.7','14-20'),(10,'American Lager','1.040-46','1.006-10','3.8-4.5','2-4','2.6-2.7','5-17'),(11,'American Light Lager','1.024-40','1.002-08','3.5-4.4','2-4','2.6','8-15'),(12,'American Pale Ale','1.044-56','1.008-16','4.5-5.5','4-11','2.2-2.8','20-40'),(13,'American Pilsener','1.045-60','1.012-18','5-6','3-6','2.6-2.7','20-40'),(14,'American Premium Lager','1.046-50','1.010-14','4.3-5','2-8','2.6-2.7','13-23'),(15,'American Wheat','1.030-50','1.004-18','3.5-4.5','2-8','2.3-2.6','5-17'),(16,'Bamberg Rauchbier','1.048-52','1.012-16','4.3-4.8','10-20','2.2-2.6','20-30'),(17,'Barley Wine','1.085-120','1.024-32','8.5-12.2','14-22','1.3-2.3','50-100'),(18,'Belgian Dubbel','1.050-70','1.012-16','6-7.5','10-14','1.9-2.4','18-25'),(19,'Belgian Fruit Lambic','1.040-72','1.008-16','5-7','no_data','2.6-4.5','15-21'),(20,'Belgian Gueuze Lambic','1.044-56','1.000-10','5-6','6-13','3.0-4.5','11-23'),(21,'Belgian Lambic','1.044-56','1.000-10','5-6','6-13','3.0-4.5','11-23'),(22,'Belgian Pale Ale','1.044-54','1.008-14','4-6.2','3.5-12','1.9-2.5','20-30'),(23,'Belgian Strong Ale','1.064-96','1.012-24','7-11','3.5-20','1.9-2.4','20-50'),(24,'Belgian Tripel','1.060-96','1.016-24','7-10','3.5-5.5','1.9-2.4','20-25'),(25,'Belgian White (Wit)','1.044-50','1.006-10','4.8-5.2','2-4','2.1-2.6','15-25'),(26,'Berliner Weisse','1.028-32','1.004-06','2.8-3.4','2-4','3.5','3-6'),(27,'Bire de Garde','1.060-80','no_data','4.5-8','8-12','no_data','25-30'),(28,'Bock','1.066-74','1.018-24','6-7.5','20-30','2.2-2.7','20-30'),(29,'Bohemian Pilsener','1.044-56','1.014-20','4.1-5.1','3-5','2.3-2.5','35-45'),(30,'Brown Porter','1.045-60','1.008-16','4.5-6','20-30','1.7-2.5','20-30'),(31,'California Common','1.040-55','1.012-18','3.6-5','8-17','2.4-2.8','35-45'),(32,'Cream Ale','1.044-56','1.004-10','4.2-5.6','2-5','2.6-2.7','10-22'),(33,'Doppelbock','1.074-80','1.020-28','6.5-8','12-30','2.3-2.6','17-27'),(34,'Dortmunder/European Export','1.048-56','1.010-14','5-6','3-5','2.6','23-29'),(35,'Dunkelweizen','1.048-56','1.008-16','4.8-5.4','16-23','3.6-4.5','10-15'),(36,'Dsseldorf Altbier','1.044-48','1.008-14','4.3-5','11-19','2.2-3.1','25-48'),(37,'Eisbock','1.092-116','no_data','8.6-14.4','18-50','2.4','26-33'),(38,'English Best (Special) Bitter','1.038-45','1.006-12','4.1-4.8','12-14','0.75-1.3','28-46'),(39,'English Brown','1.040-50','1.008-14','4-5.5','15-22','1.5-2.3','15-25'),(40,'English Dark Mild','1.030-38','1.004-08','3.2-4.0','17-34','1.3-2.0','10-24'),(41,'English Light Mild','1.030-38','1.004-08','3.2-4','8-17','1.3-2.0','10-24'),(42,'English Old/Strong Ale','1.055-75','1.008-20','6-8','10-16','1.5-2.3','30-40'),(43,'English Ordinary Bitter','1.033-38','1.006-12','3-3.7','8-12','0.75-1.3','20-35'),(44,'English Pale Ale','1.044-56','1.008-16','4.5-5.5','4-11','1.5-2.3','20-40'),(45,'English Strong (Extra Special) B','1.046-60','1.010-16','4.8-5.8','12-14','0.75-1.3','30-55'),(46,'Flanders Brown','1.044-56','1.008-16','4.8-5.2','12-18','1.9-2.5','15-25'),(47,'Foreign-Style Stout','1.052-72','1.008-20','6-7.5','40+','2.3-2.6','30-60'),(48,'German Pilsener','1.044-50','1.006-12','4.6-5.4','3-4','2.5','30-40'),(49,'Helles Bock','1.066-68','1.012-20','6-7.5','4-10','2.2-2.7','20-35'),(50,'Imperial Stout','1.075-90','1.020-30','7-9','20+','1.5-2.3','50-80'),(51,'India Pale Ale','1.050-70','1.012-18','5-7.5','8-14','1.5-2.3','40-60'),(52,'Irish Dry Stout','1.038-48','1.008-14','3.8-5','40+','1.6-2.0','30-40'),(53,'Klsch','1.042-46','1.006-10','4.4-5','3.5-5','2.4-2.7','20-30'),(54,'Maibock','1.066-68','1.012-20','6-7.5','4-10','2.2-2.7','20-35'),(55,'Mrzen/Oktoberfest','1.050-56','1.012-120','5.3-5.9','4-15','2.6-2.7','18-25'),(56,'Mnchner Helles','1.044-50','1.008-12','4.5-5.5','3-5','2.3-2.7','18-25'),(57,'Munich Dunkel','1.052-56','1.014-18','4.5-5','17-20','2.2-2.7','16-25'),(58,'North German Altbier','1.040-55','1.008-','4.3-5','11-19','2.2-3.1','25-40'),(59,'Oatmeal Stout','1.038-56','1.008-20','3.8-6','20+','no_data','20-40'),(60,'Oud Bruin','1.044-56','1.008-16','4.8-5.2','12-18','1.9-2.5','15-25'),(61,'Robust Porter','1.045-60','1.008-16','5.1-6.6','30+','1.8-2.5','20-30'),(62,'Schwarzbier','1.044-52','1.012-16','3.8-5','25-30','2.2-2.6','22-30'),(63,'Scottish Export Ale','1.040-50','1.010-18','4.0-4.5','10-19','0.75-1.3','15-25'),(64,'Scottish Heavy Ale','1.035-40','1.010-14','3.5-4','10-19','0.75-1.3','12-20'),(65,'Scottish Light Ale','1.030-35','1.006-12','2.8-5','8-17','0.75-1.3','9-20'),(66,'Strong Scotch Ale','1.072-85','1.016-28','6.2-8','10-25','1.5-2.3','25-35'),(67,'Sweet Stout','1.045-56','1.012-20','3-6','40+','2.0-2.4','15-25'),(68,'Traditional Bock','1.066-74','1.018-24','6-7.5','20-30','2.2-2.7','20-30'),(69,'Vienna','1.048-56','1.012-18','4.8-5.4','8-12','2.4-2.6','22-28'),(70,'Weizen/Weissbier','1.046-56','1.008-16','4.9-5.5','3-9','3.6-4.5','10-15'),(71,'Weizenbock','1.066-80','1.016-28','6.9-9.3','5-30','3.7-4.7','10-15');

# Dumping data for table 'beer_types'
#

INSERT INTO beer_types (id, name, description) VALUES (1,'Stout','Very dark and heavy, with roasted unmalted barley and, often, caramel malt or sugar. Invented by Guinness as a variation on traditional porter.  Russian Imperial stout is stronger than dry stout and has a bitter-burnt overtone. A sweeter, less bitter version is oatmeal stout, which uses oats in addition to barley malt. So-called espresso stouts have a strong coffeeish flavor from the malt.'),(2,'Porter','Very bitter, very dark, this beer was developed in England as a nourishing drink for manual laborers such as porters.'),(3,'Ale','These styles offer slightly bitter flavors from hops. The varying reddish, amber and golden shades come from the use of different types of malt. Ales use a different type of yeast, which ferments more rapidly and at a higher temperature, results in a more aromatic and fruity product.'),(4,'IPA','Indian Pale Ale. The name is often shortened to IPA. This ale was originally brewed in England for export to India. The large quantities of hops added were intended as a preservative and to mask potential off-flavors that might develop during the long voyage.\r\n'),(5,'Pilsner','This is the term for the classic lager originally developed in Czechoslovakia, a pale, golden-hued, light beer after which many mass-produced American beers are modeled.\r\n'),(6,'Mead','An ancient type of alcohol, not technically beer, which is made by fermenting honey.'),(7,'Lager','The main difference between lagers and ales is the type of yeast that is used. Lagers are also fermented and stored for longer periods and at cooler temperatures. In general, lagers tend to have a cleaner, drier taste than ales. \r\n\r\n'),(8,'Bitter','A British style, highly hopped for a more dry and aromatic beer, pale in color but strong in alcohol content.\r\n'),(9,'Wheat','(Weizen): Malted wheat, in addition to barley, is used for this German style beer.'),(10,'Cider','A favorite in England\'s pubs, this sweet drink is usually made from fermented apple juice and spices.'),(11,'Barley Wine','A Barley Wine is a strong, top-fermenting ale, with an alcohol content of between 9% and 13% by volume. Hops may be hardly noticeable at all or very noticeable. It is also one of the few beers that benefits from \"cellaring.\" This heavy, powerful ale has a finish that warms the throat, making it a popular winter brew.');

# Dumping data for table 'ingredients'
#

INSERT INTO ingredients (id, type, name, unit, prop1, prop2) VALUES (2,'grain','Fluffy Wiesen Grain','lbs.','12',92),(3,'Yeast','Lager Yeast','oz.',NULL,0),(82,'Misc','Garlic','cloves','honest.',0),(7,'Misc','Irish Moss','oz','',0),(79,'Hops','Liberty','oz.','pellet',5),(12,'Grain','MienWiesen','lbs.','39',29),(78,'Hops','Mt. Hood','oz.','pellet',6),(77,'Hops','Willamette','oz.','pellet',5),(15,'Grain','British Special B','lbs.','220',30),(16,'Grain','Belgian Munich light malt','lbs.','8',38),(17,'Grain','Victory dark malt','lbs.','25',34),(18,'Grain','American 2-row Pale Malt','lbs.','1.8',37),(19,'Grain','American 6-row Pale Malt','lbs.','1.8',35),(20,'Grain','Belgian pale malt','lbs.','3',37),(21,'Grain','British Pale malt','lbs.','1.6',38),(22,'Grain','German Pilsner pale malt','lbs.','1.6',38),(23,'Grain','Wheat malt','lbs.','2',38),(24,'Grain','British Pilsner','lbs.','1.8',36),(25,'Grain','American Vienna','lbs.','4',35),(26,'Grain','British mild','lbs.','4',37),(27,'Grain','Belgian biscuit','lbs.','24',35),(28,'Grain','British Amber','lbs.','35',32),(29,'Grain','American crystal 10L','lbs.','10',35),(30,'Grain','American crystal 20L','lbs.','20',35),(31,'Grain','American crystal 60L','lbs.','55',34),(32,'Grain','British chocolate','lbs.','475',34),(33,'Grain','Barley (Black Roasted)','lbs.','450',28),(34,'Grain','Barley (flaked)','lbs.','2.2',32),(35,'Grain','Barley (raw)','lbs.','2.2',32),(36,'Grain','Oats (flaked)','lbs.','2.2',33),(37,'Grain','Rice (flaked)','lbs.','.5',40),(38,'Hops','Amarillo','oz.','pellet',8),(39,'Hops','Admiral','oz.','pellet',14),(40,'Hops','Bullion','oz.','pellet',7),(41,'Hops','Brambling Cross','oz.','pellet',6),(42,'Hops','Brewers Gold','oz.','pellet',6),(43,'Hops','Challenger','oz.','pellet',7),(44,'Hops','Centennial','oz.','pellet',10),(45,'Hops','Cluster','oz.','pellet',7),(46,'Hops','Erocia','oz.','Pellets',10),(47,'Hops','Fuggles','oz.','Pellets',5),(48,'Hops','Gelena','oz.','pellet',13),(49,'Hops','Hersbrucker','oz.','pellet',3),(50,'Yeast','Distiller\'s Yeast','oz.','',0),(51,'Yeast','Doric','oz.','',0),(52,'Yeast','Edme Ale Yeast','oz.','',0),(53,'Yeast','Danstar Windsor Ale','oz.','',0),(54,'Yeast','Fleishmans Lager','oz.','',0),(55,'Yeast','Coopers Ale','oz.','',0),(56,'Yeast','Morgans Lager','oz.','',0),(57,'Yeast','Amsterdam Lager','oz.','',0),(58,'Hops','Cascade','oz.','pellet',5),(59,'Misc','Oak Chips','tsp.','',0),(60,'Grain','American crystal 40L','lbs.','40',38),(61,'Grain','Light Malt syrup','lbs.','6',37),(62,'Grain','Amber Malt syrup','lbs.','14',37),(63,'Grain','Dark Malt syrup','lbs.','40',34),(64,'Hops','Tettnanger','oz.','pellet',4),(65,'Hops','Northern Brewers','oz.','Pellets',7),(66,'Grain','British Black Patent','lbs.','500',28),(67,'Grain','Corn (Flaked)','lbs.','.5',40),(68,'Grain','Honey','lbs.','0',42),(69,'Grain','Wheat extract','lbs.','2',37),(70,'Hops','Hallertauer','oz.','pellet',5),(71,'Yeast','Wyeast Belgian Wit','oz.','',0),(72,'Misc','Corriander','oz','',0),(73,'Misc','Orange Peel','oz','',0),(74,'Grain','Rice extract','lbs.','0',34),(75,'Grain','Sugar (Brown)','lbs.','14',45),(76,'Grain','Dextrine malt (cara-pils)','lbs.','1.8',33),(80,'Hops','Chinook','oz.','pellet',12),(83,'Hops','Kent Goldings','oz.','Pellets',6),(84,'Misc','Gypsum','tsp','',0),(85,'Misc','Yeast Nutrient','tsp','',0),(86,'Misc','Citric Acid','tsp','',0),(87,'Misc','Ginger Root','oz','',0),(88,'Yeast','White Labs Sweet Mead yeast','oz.','',0),(89,'Yeast','Ale Yeast','oz.','',0),(90,'Misc','Brewing Crystals','tsp','',0),(91,'Hops','Saaz (Czech)','oz.','Pellets',4),(92,'Yeast','London Ale Yeast','oz.','',0),(93,'Misc','Nutmeg','oz','',0),(94,'Yeast','Red Star Champagne Yeast','oz.','',0),(127,'Misc','Blackberries (Frozen)','lbs.','',0),(96,'Misc','Cinnamon','sticks','',0),(97,'Misc','Cloves (whole)','tbsp','',0),(98,'Misc','lemon (juice and zest)','','',0),(99,'Grain','Maple Syrup','lbs.','3',30),(100,'Grain','DME (Amber)','lbs.','25',45),(101,'Grain','DME (Light)','lbs.','7',45),(102,'Grain','DME (Dark)','lbs.','70',45),(103,'Grain','Sugar (Cane)','lbs.','0',46),(104,'Grain','Sugar (Corn)','lbs.','0',37),(105,'Grain','Molasses','lbs.','3',36),(106,'Grain','American Chocolate','lbs.','350',29),(108,'Grain','Apple juice','lbs.','1',5),(109,'Grain','Cider (Sweet)','lbs.','1',10),(110,'Yeast','Red Star Epernay Yeast','oz.','',0),(111,'Misc','Red Raspberries','oz','',0),(112,'Yeast','London ESB Ale Wyeast','oz.','',0),(113,'Yeast','White Labs English Ale','oz.','',0),(114,'Hops','East Kent Golding','oz.','Pellets',5),(115,'Grain','Crystal -80L','lbs.','80',34),(116,'Misc','Unsweetened baker\'s chocolate','oz','',0),(117,'Hops','Target','oz.','Pellets',8),(118,'Misc','Unsweetened cocoa','oz','',0),(119,'Misc','Coffee Beans','oz','',0),(120,'Misc','Smoked Peat','oz','',0),(121,'Misc','Licorice','sticks','',0),(122,'Yeast','Wyeast 1214 (Belgian Ale)','oz.','',0),(123,'Yeast','Wyeast Swedish Porter','oz.','',0),(124,'Misc','Mint','stalks','',0),(125,'Grain','Wheat (raw)','lbs.','2',37),(126,'Misc','Cumin seed','oz','',0),(128,'Grain','Sugar (Candi - Amber)','lbs.','14',46),(129,'Grain','Sugar (Candi - Light)','lbs.','2',46),(130,'Misc','Spruce (fresh)','oz','',0),(131,'Hops','Yakima Magnum','oz.','Pellets',14),(132,'Hops','Saaz (US)','oz.','Pellets',4),(133,'Hops','Perle','oz.','Pellets',8),(134,'Hops','Crystal Hops','oz.','Pellets',4),(135,'Grain','Black Patent malt','lbs.','520',28),(137,'Misc','Frogs Bladders (powdered)','Oz','Used as a fining agent in many of Coors beers',0),(138,'Grain','Belgian Pilsner','lbs.','2.2',0),(139,'Yeast','White Labs 830 Pilsner Lager','oz.','',0),(140,'Grain','Belgian Pilsner','lbs.','2.2',0),(141,'Yeast','Wyeast 1028 London Ale','oz.','',0),(142,'Yeast','RTP Scotch Ale','oz.','',0),(143,'Grain','American crystal 120L','lbs.','120',38),(144,'Grain','Peated Malt','lbs.','20',34),(145,'Grain','Roasted Malt','lbs.','80',32);

# Dumping data for table 'recipe_lookup'
#

INSERT INTO recipe_lookup (recipe_id, ing_id, amount, boiltime) VALUES (20,31,0.5,NULL),(5,53,1,NULL),(15,21,0.5,NULL),(5,60,0.5,NULL),(11,60,1.5,NULL),(20,44,1,60),(11,58,1,60),(19,7,1,NULL),(19,80,0.5,30),(19,75,1,NULL),(15,21,5,NULL),(15,3,1,NULL),(19,61,6.6,NULL),(18,58,1,45),(5,58,3,60),(18,18,10,NULL),(11,61,7,NULL),(17,42,1,60),(20,25,1,NULL),(19,83,0.5,2),(11,52,1,NULL),(5,30,1,NULL),(5,16,2,NULL),(15,64,1.5,60),(5,22,7,NULL),(15,30,1,NULL),(18,30,1,NULL),(5,59,1,NULL),(5,7,0.5,NULL),(5,18,0.5,NULL),(11,76,0.5,NULL),(5,58,0.5,3),(19,55,1,NULL),(19,83,1,60),(19,17,1,NULL),(18,17,1,NULL),(18,71,1,NULL),(18,83,1,5),(18,83,1,30),(18,83,2,60),(8,44,1,60),(7,61,6,NULL),(7,7,1,NULL),(7,64,1,15),(8,19,1,NULL),(7,65,1.25,45),(7,3,1,NULL),(7,22,1,NULL),(8,52,1,NULL),(8,7,1,NULL),(8,47,1,15),(8,31,0.8,NULL),(17,60,1,NULL),(15,64,0.5,15),(8,61,5,NULL),(9,21,7,NULL),(10,68,2,NULL),(9,3,2,NULL),(9,60,0.25,NULL),(9,32,0.15,NULL),(9,36,0.8,NULL),(9,43,1.5,60),(10,69,4,NULL),(9,67,1,NULL),(10,70,1,60),(10,70,0.5,15),(10,71,1,NULL),(10,72,1,NULL),(10,73,1,NULL),(11,58,0.5,30),(11,58,0.5,1),(17,47,0.5,15),(17,47,0.5,30),(17,7,1,NULL),(17,53,1,NULL),(17,43,0.25,60),(17,21,8,NULL),(20,58,1,60),(20,44,0.5,15),(20,58,0.5,2),(20,44,0.5,2),(20,61,3,NULL),(20,61,4,NULL),(23,53,1,NULL),(23,47,2,60),(23,62,7,NULL),(23,32,0.25,NULL),(23,83,1,3),(23,33,0.25,NULL),(23,31,0.75,NULL),(24,68,12,NULL),(24,83,1,60),(24,7,0.25,NULL),(24,88,1,NULL),(24,87,2,NULL),(24,86,5,NULL),(24,85,3,NULL),(24,84,1.25,NULL),(25,63,7,NULL),(25,65,1.5,60),(25,89,1,NULL),(25,34,1,NULL),(25,33,0.75,NULL),(25,90,1,NULL),(26,22,3,NULL),(26,43,1,60),(26,3,1,NULL),(26,7,1,NULL),(26,68,2.5,NULL),(26,43,0.5,10),(26,29,1,NULL),(27,68,3,NULL),(27,39,1.5,60),(27,71,1,NULL),(27,72,0.5,NULL),(27,16,0.5,NULL),(27,7,0.5,NULL),(27,22,0.5,NULL),(27,73,1,NULL),(28,23,7,NULL),(28,70,2,60),(28,71,1,NULL),(28,7,0.5,NULL),(28,32,0.25,NULL),(28,58,1,3),(28,84,3,NULL),(28,76,0.5,NULL),(28,33,0.25,NULL),(29,61,4,NULL),(29,64,2,60),(29,3,1,NULL),(29,7,1,NULL),(29,31,0.5,NULL),(29,64,0.5,15),(29,70,0.25,2),(29,70,0.25,0),(29,76,2.5,NULL),(34,87,2,NULL),(34,99,2,NULL),(34,94,3,NULL),(34,108,40,NULL),(34,93,0.5,NULL),(32,61,6.6,NULL),(32,31,0.5,NULL),(32,32,0.25,NULL),(32,83,0.5,15),(34,97,2,NULL),(34,98,3,NULL),(34,96,10,NULL),(35,109,40,NULL),(35,94,12,NULL),(35,75,3,NULL),(35,68,3,NULL),(36,109,5,NULL),(36,110,3,NULL),(36,111,40,NULL),(36,109,40,NULL),(37,75,2.5,NULL),(37,89,6,NULL),(37,108,40,NULL),(38,61,6.6,NULL),(38,115,1.5,NULL),(39,66,0.24,NULL),(38,113,6,NULL),(38,7,1,NULL),(38,66,0.25,NULL),(38,106,0.4,NULL),(38,36,0.4,NULL),(38,114,1.25,60),(39,47,1,15),(39,92,6,NULL),(39,116,2,NULL),(39,117,1,60),(39,106,0.25,NULL),(39,33,0.25,NULL),(39,63,7,NULL),(41,62,4,NULL),(41,114,0.5,45),(41,89,6,NULL),(41,114,0.5,15),(41,118,1,NULL),(41,106,0.17,NULL),(41,100,0.75,NULL),(41,119,2,NULL),(42,109,40,NULL),(42,110,4,NULL),(42,72,1,NULL),(42,68,2.5,NULL),(42,93,1,NULL),(42,99,2.5,NULL),(42,97,2,NULL),(43,18,8.6,NULL),(43,77,1.35,60),(43,31,0.5,NULL),(43,106,1.5,NULL),(43,66,1.2,NULL),(43,120,2.5,NULL),(43,113,6,NULL),(43,39,0.25,30),(43,66,0.1,NULL),(44,106,0.5,NULL),(44,65,1.5,60),(44,113,6,NULL),(44,66,1,NULL),(44,64,1,15),(44,76,1,NULL),(44,102,3.3,NULL),(44,100,3,NULL),(44,121,2,NULL),(45,33,0.5,NULL),(45,65,1.5,0),(45,31,0.75,NULL),(45,106,0.8,NULL),(45,66,0.25,NULL),(45,61,6.6,NULL),(45,101,2,NULL),(45,99,0.8,NULL),(46,68,2,NULL),(46,61,6,NULL),(46,101,1,NULL),(46,58,1,5),(46,70,2,60),(46,62,1,NULL),(46,32,0.25,NULL),(47,101,5,NULL),(47,114,2,60),(47,7,1,NULL),(47,76,0.5,NULL),(47,83,0.5,30),(47,89,3,NULL),(47,60,0.5,NULL),(47,75,0.4,NULL),(48,60,0.5,NULL),(48,114,5,60),(48,106,0.25,NULL),(48,66,0.25,NULL),(48,47,3,60),(48,61,13.5,NULL),(48,105,1,NULL),(48,89,6,NULL),(49,101,4.5,NULL),(49,70,1,60),(49,122,6,NULL),(49,72,1.5,NULL),(49,68,2,NULL),(49,70,1,5),(49,73,0.5,NULL),(50,66,0.3,NULL),(50,65,1,60),(50,116,1.4,NULL),(50,75,2,NULL),(50,58,0.5,60),(50,123,3,NULL),(50,106,0.5,NULL),(50,31,1,NULL),(50,61,7.25,NULL),(50,58,0.5,30),(50,33,0.3,NULL),(50,124,5,NULL),(51,62,3,NULL),(51,83,0.5,60),(51,52,3,NULL),(51,87,6,NULL),(51,101,3,NULL),(51,78,0.5,45),(51,7,1,NULL),(51,78,0.5,15),(52,22,3.3,NULL),(52,70,2,60),(52,71,3,NULL),(52,72,1,NULL),(52,73,0.5,NULL),(52,69,2.2,NULL),(52,83,0.5,30),(52,36,0.4,NULL),(52,34,0.2,NULL),(52,126,0.05,NULL),(52,125,1,NULL),(52,98,2,NULL),(32,7,1,NULL),(32,42,1,60),(0,7,1,NULL),(0,7,1,NULL),(54,7,1,NULL),(32,89,1,NULL),(0,69,4,NULL),(0,69,4,NULL),(0,102,3,NULL),(0,70,1.5,60),(0,113,1,NULL),(0,102,3,NULL),(0,70,1.5,60),(0,113,1,NULL),(59,102,3,NULL),(59,70,1.5,60),(59,113,1,NULL),(59,127,4,NULL),(59,31,1,NULL),(59,47,0.5,5),(59,66,0.5,NULL),(59,33,0.5,NULL),(59,18,2,NULL),(59,34,1,NULL),(62,100,11,NULL),(62,47,5,60),(62,89,2,NULL),(62,30,1,NULL),(62,58,0.5,5),(62,66,0.25,NULL),(62,33,0.25,NULL),(21,21,8,NULL),(21,114,2,60),(21,92,3,NULL),(21,32,0.5,NULL),(21,43,0.5,0),(21,66,0.5,NULL),(63,61,6.6,NULL),(63,29,0.25,NULL),(63,24,0.25,NULL),(63,7,1,NULL),(63,91,2.5,60),(63,70,0.5,10),(63,91,0.5,2),(63,3,3,NULL),(27,69,3,NULL),(64,69,4,NULL),(64,58,1.5,60),(64,71,1,NULL),(64,73,1,NULL),(64,100,1,NULL),(64,34,0.25,1),(64,58,0.5,15),(64,72,1,NULL),(64,68,2,NULL),(64,128,1,NULL),(64,63,1,NULL),(64,33,0.1,1),(65,36,1,NULL),(65,65,1.5,60),(65,92,3,NULL),(65,7,1,NULL),(65,31,1,1),(65,65,0.5,15),(65,135,1.75,1),(65,34,0.5,NULL),(65,63,6,NULL),(66,35,7,NULL),(66,47,1,60),(66,89,3,NULL),(66,84,1,NULL),(66,65,0.25,60),(66,66,0.25,NULL),(66,32,0.25,NULL),(66,31,0.5,NULL),(66,7,0.25,NULL),(66,47,0.5,2),(67,63,3.5,NULL),(67,70,2,45),(67,89,1,NULL),(67,102,2,NULL),(67,130,4,NULL),(68,62,11,NULL),(68,80,1,45),(68,135,0.25,1),(68,76,0.5,NULL),(68,33,0.5,1),(68,58,0.5,2),(73,18,10,1),(73,39,1,60),(73,89,2,NULL),(76,21,2.5,1),(76,60,0.5,1),(76,31,0.5,1),(76,27,0.25,1),(76,61,6,NULL),(76,101,1,NULL),(76,43,2,20),(76,80,1,20),(76,83,1,0),(76,113,1,NULL),(76,84,5,NULL),(76,7,0.5,NULL),(74,106,8,NULL),(81,106,2,NULL),(81,39,1,0),(81,89,1,NULL),(81,127,2,NULL),(81,31,1,NULL),(79,102,6,NULL),(79,70,1,50),(79,113,3,NULL),(79,84,3,NULL),(79,36,1,NULL),(79,7,1,NULL),(79,58,0.5,30),(79,66,0.5,1),(79,33,0.5,1),(79,76,0.5,NULL),(80,22,10,1),(80,91,2,60),(80,91,2,30),(80,91,1,10),(80,91,1,0),(80,3,6,NULL),(80,3,6,NULL),(82,21,6,1),(82,114,1,60),(82,31,0.75,1),(82,32,0.25,1),(82,75,1,NULL),(82,141,1,NULL),(83,21,0.25,1),(83,58,0.25,30),(83,89,1,NULL),(83,32,0.25,1),(83,47,2,60),(83,66,0.25,1),(83,47,1,0),(83,26,0.5,1),(83,60,0.5,1),(83,76,0.15,1),(83,102,2,NULL),(83,62,5,NULL),(84,62,1,NULL),(84,47,1,60),(84,31,0.5,1),(84,47,1,30),(84,143,0.75,1),(84,145,0.25,NULL),(84,142,1,NULL),(84,144,0.25,NULL),(84,21,10,1),(85,20,3,NULL),(85,58,1,0),(85,122,1,NULL),(85,72,1,NULL),(85,69,4,NULL),(87,29,1,NULL),(86,70,10,90),(86,122,0.2,NULL),(86,28,0.4,NULL),(86,32,0.04,NULL),(87,43,2,90),(87,3,1,NULL),(87,137,2,NULL),(87,30,2,NULL),(88,62,4.5,NULL),(88,65,1.5,60),(88,3,1,NULL),(88,63,3.3,NULL),(88,64,1,2),(88,135,1,1),(89,61,4,NULL),(89,70,0.5,20),(89,139,3,NULL),(89,18,1,1),(89,49,0.5,5),(89,76,0.5,1),(89,104,2,NULL),(89,45,0.5,60);

#
# Dumping data for table 'recipes'
#

INSERT INTO recipes (id, name, notes, type, sub_type, owner, size) VALUES (15,'First Lager','Place grains into strainer bag, and bring 2 1/2 gallons water to a boil.  Remove from heat, and let sit 10 minutes, then sparge grain bag with 1 quart hot water.  Add malt, bring to boil, then add boiling hops.  After 45 minutes, add 1/2 oz finishing hops. Boil for 15 more minutes.\r\nPour wort into fermentor (which already contains 2 1/2 gallons cold water). Pitch yeast when wort reaches 75 degrees F.\r\nFerment at 45-55 degrees F.  When ready, rack to secondary and ferment for another 2-3 weeks.\r\nbottle as usual.',7,10,'3',5),(5,'Phils IPA','Standard procedure for an extract brew.\r\nRack within a week, and bottle for 3 weeks.',4,51,'3',5),(7,'German Pilsner','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Don t fret the temp too much, relax. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt syrup. Return to a boil, then add boiling hops and Irish Moss and boil for 45 minutes. Add 2nd addition of hops for last 15 minutes of the boil. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 75, and ferment at 50 to 55. Cooler temperatures cause fermentation to go slower, about 3-4 weeks. Be patient!! Bottle as usual.',5,48,'3',5),(8,'Trout Ale','Fishey!\r\nThis beer is supposed to emulate the famous Bass Ale.\r\nIt does an ok job at it.\r\nThe proceedures are standard.\r\n1) Boil\r\n2) Rack\r\n3) Transfer\r\n4) Bottle\r\n5) Drink',3,7,'3',5),(9,'Best Bitter','Standard extract recipe procedure.\r\nSteep the specialty strains in the pot w/ cold water and bring to boil.  Remove grains when boiling, and add extracts and hops.  Continue boiling for 1 hour, then bring to 70-80 degrees as quickly as possible.\r\nPitch yeast and ferment.',4,51,'3',5),(10,'Belgian White Ale','Use orange blossom honey.\r\nAdd 1/2 oz. of corriander and 1/2 oz. of orange peel at last 15 minutes of boil. Add another 1/2 oz. of corriander during cooling for aroma. Add 1/2 oz. orange peel at cooling.\r\nFerment at room temp. Rack after one week. Six weeks in secondary. We were lazy and too busy to bottle. Should be OK since most of the yeast was removed at the rack to secondary. We would recommend bottling after 3 weeks in secondary.',9,25,'4',5),(11,'Scottish Ale','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt sugar. Return to a boil, then add 1 oz boiling hops and boil for 60 minutes. Add Irish Moss for last 45 minutes of boil. Add  oz boiling hops for last 30 minutes of boil. Add finishing hops for last 1 minute of the boil. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 78, and ferment and bottle as ususal.\r\n\r\n',3,64,'3',5),(17,'Garlic Ale','Yes Garlic was used. Whe man who gave me the recipe claimed that it turned out pretty damn good. I took some artistic license with his recipe. 5 crushed cloves of garlic were added as the wort was brought to a boil. Skimmed off with the foam as the boil started. 15 mins before the end of the boil 5 heads, yes heads!, of roasted garlic were added with the irish moss.\r\nMash:\r\n120 degrees F for 15 min by addition of 130 degree water. Added 165 degreee water to bring to 145. 15% decoction pulled and brought to boil. Added back to bring temp to 154 degrees. Mashed for 45 more mins.',3,1,'3',5),(18,'Dead Dog IPA','I infusion mashed the 11 lbs. total grain with 3 gallons of\r\ntreated water at 155F for 90 minutes. Checked for conversion at 60 minutes, it wasn\'t complete waited 15 minutes more for full conversion.\r\nfermentation temp 70F.\r\nPrimed with 1 cup corn sugar disolved in 1 cup filtered water',4,51,'3',5),(19,'English Cream Ale','Boil 1 gallon water. Remove from heat. Steep Victory malt in a muslin bag for 45 minutes. Sparge grains with 1 gallon boiling water.\r\n\r\nUse liquid from sparged grain for boil. Add 1 gallon water and bring to a boil. Add all malt extract and sugar. Add hops as scheduled.\r\nAdd 1 tsp. Irish Moss to boil for last 10 minutes.\r\n\r\nDry hop by adding 1 ounce Kent Goldings pellets directly to primary fermenter. Allow fermentation to proceed for 1 week. Siphon brew into glass carboy leaving behind the majority of the hops. Allow brew to finish fermentation for \r\napproximately 4-5 more days.\r\n',3,32,'3',5),(20,'Hop Head IPA','Tastes good, but is very bitter.\r\nFresh hops help.',4,51,'3',5),(21,'Brown Porter','Any worries were pretty much for naught cause this is probably my best brew yet. Its sweet and chocolaty. Nice mouthfeel, incredible had retention. Belgian lace. And the yeast really sticks to the bottom of the bottle so you dont get a lot of floaties in your glass. Who-ha-ha-ho! Cant wait to get home from work to have another one. Whooahooa! Sorry, that was a little overkill. Next time (and I will make this again. Oh, yes. I will make this again) Ill cut back on the priming sugar a bit to make it less carbonated and more creamy. \r\n<b>Directions:</b>\r\nCrack the grains a lot. Bag them. Slowly bring water up to a boil, letting it hold at around 175-200 degrees for a while. Then add your bittering hops and ME and stuff. I forget how many minutes the flavor hops went for. Maybe 10. Anyway, cool and pitch yeast. Let it ferment for a week. This is where the weird stuff happened. After 8 days, when I opened the primary to rack it to secondary, the stuff was still going full-blast. Kreusen foam and all bubbly and stuff. So I racked it anyway. I didnt want to leave it on the primary trub for too long. I was sorta worried, but it seemed fine in the secondary. Left it in there 2 weeks, bottled it. ',2,30,'3',5),(23,'Cannonball Porter','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt sugar. Return to a boil, then add boiling hops and boil for 60 minutes. Add finishing hops for last 3 minutes of the boil. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 78, and ferment and bottle as usual.',2,61,'3',5),(24,'Honeymoon Mead','Add all ingredients except yeast and corn sugar to 1 gallons water. Heat to 170 and hold temp for 30 minutes. Fill your sanitized carboy with 2 gallons cold water. Strain hot liquid into the carboy and top off to the 5 gallon mark. Cool to below 78 and pitch yeast. Ferment 10 to 14 days, then rack to secondary carboy and ferment 4 to 5 more weeks. Mead will be ready to bottle when it is crystal clear. Bottle with corn sugar as usual. Age the bottled mead for about 6 weeks, then try a bottle. Mead is a lot like wine, so be prepared to wait up to a year for it to mature completely. The dryer the mead, the longer it will take. I have found the sweeter meads quite drinkable within 6 months.\r\n',6,1,'3',5),(25,'Irish Creme Stout','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Dont fret the temp too much, relax. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt sugar. Return to a boil, then add boiling hops and Brewing Crystals and boil for 60 minutes. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 78, and ferment and bottle as ususal. Flavor will improve with aging!',1,47,'3',5),(26,'Honey Pilsner','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Dont fret the temp too much, relax. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt sugar and honey. Return to a boil, then add Willamette hops and boil for 60 minutes. Add Irish Moss for last 45 minutes of boil. Add Tettnanger hops for last 10 minutes of boil. Add finishing hops for last 2 minutes of the boil. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 78, and ferment to completion at 50 for lager yeast or 68 for ale yeasts. Bottle as ususal. ',5,1,'3',5),(27,'Belgian Fruity White','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Dont fret the temp too much, relax. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt syrup. Return to a boil, then add boiling hops and boil for 60 minutes. Add Irish Moss for last 45 minutes of boil. Add spices for last 15 minutes of the boil. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 78, and ferment and bottle as ususal.\r\n\r\n',9,25,'3',5),(28,'Dunkelweizen','Steep crushed malted grain in 2 gallons of 150 water (tap water is about 130) for 30 minutes. Dont fret the temp too much, relax. Remove the grain from the hot water with a strainer, then bring water to a boil. When boiling starts, remove pot from burner and add malt sugar. Return to a boil, then add boiling hops, Irish Moss and Gypsum and boil for 60 minutes. Add finishing hops for last 3 minutes of the boil. Fill your sanitized carboy with 2 gallons of cold water. Strain the hot wort into the carboy and top off to the 5 gallon mark. Add yeast when beer is less than 78, and ferment and bottle as ususal.\r\n\r\n',9,35,'3',5),(29,'Sam Adams Clone (extract)','Steep crystal in 1/2 gallon of 150f water for 20 min. Strain the grain and run 1/2 gallon of 150f water over the grains.  Add enough water to get 1 1/2 gallons. Bring to a boil and remove from heat. Add the extract,light DME, and bittering hops (2oz. Tettnanger). Add water to 2 1/2 gallons and boil for 45 min.  Add flavor hops (1/4oz Hallertauer) and irish moss. Boil for 13 minutes and add the aroma hops(1/2oz. Tettnanger).  Boil for 2 more min. Remove from stove, cool,place in fermentor,and add enough water to make 5 gallons.Pitch yeast and ferment cool(55f).Rack to secondary and add the dry hops (last 1/4oz. of Hallertauer). \r\n\r\nPrimary for 10 days@55. \r\nO.G.-1.050 \r\nF.G.-1.012 \r\nAlcohol-5.0% ',7,9,'3',5),(34,'Holiday Cider','(40lbs = 5 gallons)\r\nSimmer 3/4 gallon apple juice, spices and ginger (in spice bags), syrup, and lemon juice and zest for 45 mins. Add simmered mix to 4--1/4 gallon. Put cider in carboy. Pitch yeast and top off with more apple juice. Ferment for 34 days. Rack to secondary and top off with more apple juice. Prime with 3/4 cup corn sugar and bottle. Age for 30 days and consume. ',10,1,'3',5),(35,'Hard Cider','(40lbs = 5 gallons)\r\nStrain 3 gallons of cider into a 5-gallon carboy. Strain 1/2 gallon into pot and heat enough to allow sugar and honey to thoroughly dissolve. Pour into carboy and finish filling to neck. Pitch yeast and seal with airlock. When fermentation stops, bottle. Prime with sugar to add carbonation. ',10,1,'3',5),(32,'Petes Wicked Clone','Steep grain in 1/2 gallon of 150 water for 20 min.Sparge with 1/2 gallon of 165 water and accumulate to 3 gallons. Bring to a boil, remove from heat, add extract, and Brewers Gold. Boil for 45 min. And add tht irish moss and east kents. Boil for another 15 min. Force cool, add yeast, and ferment. ',3,7,'3',5),(36,'Raspberry Cider','(40 lbs = 5 gallons)\r\nToss all ingredients into a carboy at room temperature. Put on an airlock and go away. Rack after 2-3 weeks and go away again. After another 2-3 weeks bottle and go away for a few months! ',10,1,'3',5),(37,'Simplest Cider','1. Reserve 3 cups of juice (put back after fermenting)\r\n2. Add yeast and shake (pitch)\r\n3. Airlock and leave at room temperature\r\n4. Fermentation will last 6 to 8 days in warm weather\r\n5. Put in frig for 1 or two days\r\n6. Rack and prime bottles with 6 teaspoons of sugar or corn syrup\r\n7. Drink or lay it down ',10,1,'3',5),(41,'Mocha Brown Ale','Steep the crystal and chocolate malts and coffee beans in 2.5 gallons of cold water. Gradually raise heat to 150 F, hold 30 minutes. Remove grains and rinse them back into the pot with hot water. Stir in dry malt and ground cocoa, bring to boil. Boil 15 minutes, add half the hops. Boil 30 minutes, add the rest of the hops. Boil 15 minutes, remove from heat, cool 15 minutes. Add to fermenter along with enough chilled, pre-boiled water to make 5.25 gallons. Cool to 70 F, pitch yeast. Seal and ferment for seven days, rack to secondary and age in a cool dark place for ten days. Prime and bottle. Bottle condition cool and dark for two weeks. \r\n',3,1,'3',5),(38,'Slow Elk','Steep specialty grains in about 3 gallons of water at 150 to 155 F for 30 minutes. Remove grains, and add malt syrup and bring to a boil. Add 1.25 ounces Kent Golding hops and 1 teaspoon Irish moss and boil for 60 minutes. When done boiling, strain out hops and add the wort to cool water in a sanitized carboy to fill to the 5-1/2 gallon mark. Add your yeast when the wort is 75 to 80 F, and aerate well. Let the wort cool to about 68 F over the next few hours and ferment at 66 to 70 F until complete (normally 7 to 10 days). \r\n\r\nAll-grain option \r\nReplace Coopers malt extract with 7.5 pounds of pale malt. Mash grains together for 60 minutes at 155. Collect enough wort to boil for 90 minutes and have 5.5 gallons yield. Decrease boiling hops to 1 ounce (5 AAU) to account for increased hop extraction efficiency in a full boil. The remainder of the recipe is the same as the extract. ',1,67,'3',5),(39,'Bitter Chocolate','Steep the black and chocolate malts and the roasted barley in 2.5 gallons of cold water. Gradually raise heat to 150 F, hold 30 minutes. Remove grains and rinse them back into the pot with hot water. Stir in dry malt and baker\\\'s chocolate, bring to boil. Boil 15 minutes, add Target hops. Boil 45 minutes, add Fuggles hops. Boil 15 minutes, remove from heat, cool 15 minutes. Add to fermenter along with enough chilled, pre-boiled water to make 5.25 gallons. Cool to 70 F, pitch yeast. Seal and ferment for ten days, rack to secondary and age in a cool dark place for a month. Prime with dry malt and bottle. Bottle condition cool and dark for a month or more.',1,67,'3',5),(42,'Spicey Cider','Boil 1/2 gallon of cider with the spices, honey and syrup for 30 minutes.  If not using boiling bags for spices, strain off as much as possible.\r\nPitch yeast at 75-80 degrees, and ferment.\r\nRack if desired.\r\nAdd priming sugar for carbonation when bottling.',10,1,'3',5),(43,'Perfect Porter','Single temp infusion at 154F for 75 minutes.\r\nSparge with 3 gallons at 150F.',2,61,'3',5),(44,'Po Boy Porter','Put grains in bag and begin heating water.\r\n@ 120 rest for 15 min. then raise to\r\n155 and rest for 30 min. Remove grains, mix extracts and\r\nbring to boil.\r\nPlace 2 in. Licorice stick in plastic bag and crush with hammar. Put in wort during last 30 min. Stir often to help disolve',2,61,'3',5),(45,'Maple Porter','Add all grains in a steeping bag, when water comes to a boil remove steeping bag.  Add maple syurp, 2 min before the end of the boil\r\n\r\n2/4 cup corn sugar for bottling, takes 2 months to fully carbonate beautifull head.',2,61,'3',5),(46,'Ill be bock','None give.\r\n\r\nup to the brave?',7,28,'3',5),(47,'Better Bitter','None given.\r\n\r\nall extract though.',8,38,'3',5),(48,'Warm n Fuzzy','Steep the grains for 30 minutes at 150. Then remove them before raising the temp to boiling.\r\nI do a full 5 gallon boil. If you boil less than that youll have to increase the hops to get the same final result.\r\nWyeast 1028 does a nice job with this.\r\nLet ferment for many a month.',11,17,'3',5),(49,'Tamalpais Wit','Bring 5 gallons of water to a boil, then add first three ingredients. \r\nBoil 45 minutes, then add 3/4 oz. coriander. Boil 10 minutes, then add remaining coriander and orange peel.\r\nBoil 5 minutes, and add the finishing hops for a final 2 minutes. Chill immediately to 75 F, areate into 5 gallon carboy, and add yeast. Ferment using blow-off method, then prime with 3/4 cup corn sugar and bottle.\r\n\r\n\r\nThe keys to making this beer are (1) use belgian ale yeast, (2) crush the coriander yourself, so it is nice and\r\nfresh, (3) use orange honey, and (4) use the best Hallertauer hops you can find. Papazian\'s basic recipe is\r\nvery flexible; Ive made 5 different beers so far by changing the malt combinations, and Ive liked them all. I like this one the best so far. \r\n',9,25,'3',5),(50,'Mint Porter','Mash cracked grains @155 deg f. for 1 hour add malt, hops, sugar and chocolate and boil for 30 min. add rest of hops and boil for 30 min \r\n\r\ncool pitch ferment...\r\n\r\nwhen in the secondary prepare approximatly 5 8 inch stalks with leaves of Fresh Mint buy putting in 2 cups of water and heating to 180 deg f. and holding for 30 min to kill off any cooties that might be on the leaves.\r\n\r\nAdd water AND mint leaves to the secondary for 2 weeks, prime and bottle\r\nVery refreshing with a slight warming effect\r\n\r\n',2,30,'3',5),(51,'Ginger Ale','Brew ingredients in usual way. Flavor is very gingery, but not enough to wrinkle your mouth. Very smooth. Prime with 1 C corn sugar. I waited 2 weeks, but I think its drinkable earlier than that. Fermented at 66 degrees.',3,1,'3',5),(52,'Hoegaarden-like','Hoegaarden Wit should have an OG if 1048. Kent Goldings is used for the sec character and Saaz is used for the aroma. Michael Jackson suspected a third spice is used, perhaps cumin seed, Ive received a tip not to use too much of this seed because it seems to give a cheesy result, try starting with a single (1) gram. \r\nThe wort is fermented by two different strains of yeast, one for the primary fermentation, the other for the secondary (bottle) fermentation. To each bottle a bit of glucose is added together with the second yeaststrain.\r\nThe first yeast which is used to ferment Hoegaarden Wit, I have no information about this first yeast. The second yeast however can be cultivated from a bottle of Hoegaarden (or perhaps even Celis white if he took his yeaststrains with him).\r\n\r\nHops\r\nThe hops I used are 22 grams of Hallertau (boiled for 60 minutes) and 10 grams of Goldings (boiled for 30 minutes).\r\n\r\nThe coreander was boiled for 10 minutes, the peel for 7 minutes. Total boilingtime was 65 minutes.\r\nMASHING 118 125 145 163 172 (F)\r\nMINUTES 10  25  25  30  2 \r\n\r\nI added the juice of 1 lemon to the mash to obtain a pH of about 5.2.\r\n\r\nOG should be about 1049. This batch produced a nice whitebeer, which certainly can compete with the Hoegaarden. It resembled the original quite a bit, but the hoparomas were somewhat more spicier than the original. ',9,25,'3',5),(59,'Blackberry Stout','Start all the grains in brewpot with cool water, remove when boil commences. Add all malt, and Hallertauer hops. Boil 1 hour. Add Fuggles hops, boil for 5 more minutes. Remove from heat. Add thawed blackberries and steep for 15 mins. Cool and dump the whole mess in the primary. When moved to secondary, leave the blackberries behind. \r\nThis stout reaches its prime in 4-6 weeks, and rapidly deteriorates from there, aquiring a winey flavor as the residual blackberry sweetness erodes. (Amateur) Judges\r\nComment: Good and black. Good mouth feel. Unbelievable finish - seems to last forever! Fruit? I want the recipe. Nice Job. ',1,67,'3',5),(62,'Volga Crude Stout','Add specialty grains to 2 gallons of cold water. \r\nBring to a boil; then remove the grains. \r\nAdd DME and Bittering Hops and bring to an even, rolling boil. \r\nBoil for 60 minutes, stirring frequently. \r\nWARNING: This thick, heavy mixture is quite prone to boil-over! \r\nAdd Finishing Hops to the last 5 minutes of the boil. \r\nAdd 3 gallons of cold water to the fermenter \r\nStrain hot Wort into fermenter \r\nCool to 70 and pitch yeast. \r\nBottle in 10 to 12 days with corn sugar ',1,50,'6969',5),(63,'Lone Palm Pilsner','Steep grains in 2 gallons of water. \r\nTake out when boil starts and add extract and boiling hops. Add irish moss at 45 min. \r\nAdd flavor hops at 50 minutes. \r\nAdd finishing hops at 58 minutes. \r\nRemove from heat at one hour and cool to 78 degrees. Pitch yeast. Keep in primary for 4 days at 50 degrees. \r\nRack to secondary and let sit for three weeks at 50 degrees. Bottle with 1 cup corn sugar and 1c water. Let sit three weeks and enjoy!',5,29,'3',5),(64,'Brown Dog Wit','Use orange blossom honey, if possible.  \r\nAdd barley (black and flaked) to 1/2 gallon of water and raise the temperature to anywhere between 150-158F. Remove from heat, cover and let stand for 40 minutes. \r\nDump the stuff into a kitchen colander or large strainer and catch the runnings in a pot. Pour another 1/2 gallon of hot water over the grain and catch this runoff as well. \r\nAdd to 2 gallons of water to boil, and boil.  When boiling add the extract, honey, sugar (candi) and boiling hops.\r\nAdd 1/2 oz. of corriander and 1/2 oz. of orange peel at last 15 minutes of boil. Add another 1/2 oz. of corriander during cooling for aroma. Add 1/2 oz. orange peel at cooling. \r\nFerment at room temp. Rack after one week. Three to six weeks in secondary (longer due to the higher OG).',9,25,'3',5),(65,'Introspection Stout','1. Add grains (oats, crystal 60, flaked barley and black barley) to 1 1/2 gallon of water and raise the temperature to anywhere between 150-158F. Remove from heat, cover and let stand for 40 minutes.  \r\n\r\n2. Dump the stuff into a kitchen colander or large strainer and catch the runnings in a pot. Pour another 1 1/2 gallon of hot water over the grain and catch this runoff as well. \r\n\r\n\r\n3. Add dark extract and boiling hops and bring to boil for 60 minutes.  In 15 minutes before the end, add finishing hops.  \r\n\r\nCool as quickly as possible to 75 degrees, and pitch yeast.\r\n',1,59,'3',5),(66,'Monkeys Paw Brown','Add all grains and gypsum to 1.75 gallons of 168 deg F water.  It will stabilize at about 150F; hold it there for 45-60 mins.  Sparge w/ 4 gallons of 170 water.  Add 3 more quarts and bring it to boil.  Add in the boiling hops and boil for one hour.  10 minutes before the end add the moss, and 2 mins before add the 1/2 oz Fuggles.\r\nRemove hops, sparge and cool quickly.',3,39,'3',5),(67,'Island Spruce Ale','A great recipe that gives off a \"gingerbread\" smell to the whole kitchen.  The taste is wonderful... too difficult to describe, but sorta like a beer cola (in a good way, honest).\r\n\r\nDump it all into 1.5 Gallons of water, bring to boil for <b>45</b> minutes, sparge and cool.  ',3,1,'6969',5),(68,'Imperialist Stout','I boiled for 1 hour and added the hops every ten minutes or so. Near the end of the boil, I added finish hops down to the last two minutes. Adding the hops this way tends to keep the hop flavor and aroma from boiling away. \r\n\r\nBottled condition for a month. Three months would be better, but I couldnt wait. \r\n\r\nPrimary ferment: 14 days. Secondary: 10 days \r\n\r\n',1,50,'3',5),(75,'Snake Rock IPA','',3,1,'34',5),(76,'Short Boil IPA','This is a short boil partial-mash recipe.\r\nMash grains in 2 gallons of water at 152 degrees for 50 minutes.   Sparge with 1.5 gallons of 170 degree water with 5 tsp gypsum added.    Add water to 5.5 gallon level and bring to a boil.   After hot break add Challenger and Chinook hops and boil for 20 minutes.    Add 1 oz. of Kent Goldings at end of boil, or use it to dry hop in secondary.   ',4,51,'6969',5),(77,'kabegami','',0,0,'37',5),(78,'kabegamikabegami','',0,0,'37',5),(79,'Beardawg Stout','Add Gypsum to 2 1/2 gallons of water and bring to boil. As soon as first bubble surfaces, place oats and grain(in sock), turn off heat and let steep for 40 minutes(you might have to add heat after 20 mintues just to heat back up. \r\n\r\nRemove sock and strain oats out. \r\n\r\nReturn heat and bring to boil. Add Malt and Malto Dextrin(Remove from heat when adding malt). \r\n\r\nAt 10 minutes into boil, add Hallertau Hops. \r\n\r\nAt 30 minutes into boil, add Cascade Hops and Irish Moss. \r\n\r\nAt 45 minutes into boil, remove from heat, chill wort and add to fermenter top off with clean water. \r\n\r\nWhen cooled to below 80, pitch yeast and ferment for 14-21 days. I recommend racking into a glass carboy at 5-7 days. \r\n\r\nThen bottle or keg as you normally would! \r\n\r\nEnjoy!!! \r\n',1,47,'6969',5),(80,'Bohemian Pilsener','',7,29,'6969',5),(85,'Big Dave\'s','',3,22,'3',5),(82,'Mild Brown Ale','I use a recirculating infusion mash system.\r\nBoil for 75 minutes.\r\nPrimary for 9 days.\r\nThis beer won first place in the Brown Ale category at the 1996 Boston Homebrew competition. The same basic recipe with 2 lbs of honey added to the boil won a first place ribbon in the specialty beer category at the 1996 North Texas State Fair.\r\n',3,39,'7',5),(83,'Nut Brown Ale','Toast Pale malt by spreading in cookie sheet and placing in oven at 350 deg for no more that 10 min. \r\n\r\nOnce cool add to other specialty grains and crack.\r\nAdd cracked grains to 1.5 gallons of water and bring to boil\r\n\r\nOnce boil commences remove cracked grains and add malt extract, malto dextrin and 2 oz Fuggles\r\n\r\nFollow remaining guidelines as you normally would to brew\r\n\r\nThis brew gives a great nutty flavor due to the toasting procedure and the roasted barley\r\n\r\n\r\n\r\n',3,41,'7',5),(84,'St. Andy Clone','Single infusion @ 158F for first hour, 150F for second hour\r\nMash out at 175 for 10 mins\r\n\r\nBoil one gallon of first runnings down to maximum of one quart and add to last ten minutes of main boil.\r\n\r\nCool, aerate and pitch yeast.\r\n\r\nAfter fermentation, I conditioned with 1/2 cup of honey and bottled.\r\n\r\nThis brew took third place in a competition. I probably would have done better if I had entered it in the right Scottish Ale sub category. I really like this one. Enjoy!',3,63,'3',5),(86,'Westvleteren','',3,18,'6969',5),(87,'test naam','',8,10,'6969',5),(88,'Sparrow Hawk Porter','Crush the black patent malt and add to 1.5 gallons of cold water.  Bring to a boil and boil the grains for 5-10 minutes, then remove them with a strainer.  Add the malt extracts and boiling hops, and continue to boil for 60 minutes.  Add the finishing hops during the final 1-2 minutes of boil.  Sparge immediately.\r\nPitch, wait, bottle, wait and enjoy!',2,61,'6',5),(89,'Coronita','Pretty typical brew.\r\nIf you want a little less bite, use either a German Ale, or German lager yeast.\r\n\r\nMakes a decent Corona like light Mexican beer.\r\nDrink with a lime, of course!\r\n\r\n',7,11,'10',5);


UPDATE recipes SET owner=1;
